#
# spec file for package containers-systemd
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define containers bind dhcp-server haproxy mariadb nginx squid
%define container_services container-bind.service container-dhcp-server.service container-dhcp6-server.service container-haproxy.service container-mariadb.service container-nginx.service container-image-prune.timer squid.service

%if %{undefined service_del_postun_without_restart}
%define service_del_postun_without_restart() \
DISABLE_RESTART_ON_UPDATE=1 \
%service_del_postun %{?*}
%endif

Name:           containers-systemd
Version:        0.0+git20200324.5f4ae65
Release:        bp153.1.15
Summary:        Systemd service files and config files for openSUSE container
License:        MIT
URL:            https://github.com/kubic-project/containers-systemd
Source:         containers-systemd-%{version}.tar.xz
Source1:        containers-systemd.rpmlintrc
Requires(post): %fillup_prereq
BuildArch:      noarch

%description
This package contains the configuration files and systemd units
to run the openSUSE containers via podman managed by systemd.
Currently supported are bind, dhcp-server, mariadb, nginx and squid.
Additional, there is a timer to cleanup dangling container images.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_fillupdir}
for i in %{containers}; do
    mkdir -p %{buildroot}/srv/$i
    install -m 644 sysconfig.container-$i %{buildroot}%{_fillupdir}/
    install -m 644 container-$i.service %{buildroot}%{_unitdir}/
    # create symlink for rccontainer-*
    ln -s /sbin/service %{buildroot}%{_sbindir}/rccontainer-$i
done
install -m 644 container-dhcp6-server.service %{buildroot}%{_unitdir}/
ln -s /sbin/service %{buildroot}%{_sbindir}/rccontainer-dhcp6-server
install -m 644 container-image-prune.service %{buildroot}%{_unitdir}/
install -m 644 container-image-prune.timer %{buildroot}%{_unitdir}/
mkdir -p %{buildroot}%{_sysconfdir}/mariadb-secrets
for i in MYSQL_ROOT_PASSWORD MYSQL_ROOT_HOST MYSQL_DATABASE MYSQL_USER MYSQL_PASSWORD; do
  touch %{buildroot}%{_sysconfdir}/mariadb-secrets/$i
done

%pre
%service_add_pre %{container_services}

%post
for i in %{containers}; do
    %{fillup_only -n container-$i}
done
%service_add_post %{container_services}

%preun
%service_del_preun %{container_services}

%postun
# Avoid useless container restarts on update of this package
%service_del_postun_without_restart %{container_services}

%files
%license LICENSE
%doc README.md
%{_unitdir}/container-bind.service
%{_fillupdir}/sysconfig.container-bind
%{_sbindir}/rccontainer-bind
%ghost %dir /srv/bind
%{_unitdir}/container-dhcp-server.service
%{_unitdir}/container-dhcp6-server.service
%{_fillupdir}/sysconfig.container-dhcp-server
%{_sbindir}/rccontainer-dhcp-server
%{_sbindir}/rccontainer-dhcp6-server
%ghost %dir /srv/dhcp-server
%{_unitdir}/container-haproxy.service
%{_fillupdir}/sysconfig.container-haproxy
%{_sbindir}/rccontainer-haproxy
%ghost %dir /srv/haproxy
%{_unitdir}/container-mariadb.service
%{_fillupdir}/sysconfig.container-mariadb
%{_sbindir}/rccontainer-mariadb
%ghost %dir /srv/mariadb
%dir %attr(0700,root,root) %{_sysconfdir}/mariadb-secrets
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_ROOT_PASSWORD
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_ROOT_HOST
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_DATABASE
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_USER
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_PASSWORD
%{_unitdir}/container-nginx.service
%{_fillupdir}/sysconfig.container-nginx
%{_sbindir}/rccontainer-nginx
%ghost %dir /srv/nginx
%{_unitdir}/container-squid.service
%{_fillupdir}/sysconfig.container-squid
%{_sbindir}/rccontainer-squid
%ghost %dir /srv/squid
%{_unitdir}/container-image-prune.service
%{_unitdir}/container-image-prune.timer

%changelog
* Fri Apr 24 2020 Ludwig Nussel <lnussel@suse.de>
- use SLE15 compatible %%service_del_postun
* Mon Mar 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Package service file for squid conainer
* Tue Mar 24 2020 kukuk@suse.com
- Update to version 0.0+git20200324.5f4ae65:
  * Add timer to prune unnamed images
* Wed Feb 19 2020 kukuk@suse.com
- Update to version 0.0+git20200219.a6acfd1:
  * Adjust for new nginx container image
  * Fix comment
* Mon Feb 17 2020 kukuk@suse.com
- Update to version 0.0+git20200217.580c00f:
  * Add squid
* Wed Feb 12 2020 kukuk@suse.com
- Update to version 0.0+git20200212.47b21c6:
  * Add haproxy
* Thu Jan 30 2020 kukuk@suse.com
- Update to version 0.0+git20200124.e3c2408:
  * Fix network parameter for dhcp servers
* Wed Jan 22 2020 kukuk@suse.com
- Update to version 0.0+git20200122.8276c03:
  * Add support for nginx container
* Fri Jan 17 2020 Thorsten Kukuk <kukuk@suse.com>
- Use new macro to prevent restart on update
* Thu Jan 16 2020 kukuk@suse.com
- Update to version 0.0+git20200116.87baa97:
  * Start container only after network, don't abort if pull fails
* Wed Oct 30 2019 kukuk@suse.com
- Add mariadb files
- Update to version 0.0+git20191030.b2f919f:
  * Fix typo, mention which variable adjusts secrets path for mariadb
  * Add environment variables and files to initialize mariadb at first startup
  * Enhance documentation
  * Add first mariadb service and sysconfig file
  * Mention dhcp6-server
* Tue Oct 29 2019 kukuk@suse.com
- Update to version 0.0+git20191029.39ca697:
  * Provide dhcpd4 and dhcpd6 service files
* Mon Oct 28 2019 kukuk@suse.com
- Update to version 0.0+git20191028.2cbfdca:
  * Add sysconfig and service file for dhcp-server container image
* Sat Oct 26 2019 kukuk@suse.com
- Update to version 0.0+git20191026.e3a4918:
  * Add service and sysconfig file for bind container
